@@ -19,7 +19,6 @@ import pytest
 
 import google.cloud._helpers
 from google.cloud import bigquery
-from google.cloud import bigquery_v2
 
 
 @pytest.fixture
@@ -62,15 +61,15 @@ def test_ctor_w_properties(target_class):
     arguments = [
         RoutineArgument(
             name="x",
-            data_type=bigquery_v2.types.StandardSqlDataType(
-                type_kind=bigquery_v2.types.StandardSqlDataType.TypeKind.INT64
+            data_type=bigquery.standard_sql.StandardSqlDataType(
+                type_kind=bigquery.StandardSqlTypeNames.INT64
             ),
         )
     ]
     body = "x * 3"
     language = "SQL"
-    return_type = bigquery_v2.types.StandardSqlDataType(
-        type_kind=bigquery_v2.types.StandardSqlDataType.TypeKind.INT64
+    return_type = bigquery.standard_sql.StandardSqlDataType(
+        type_kind=bigquery.StandardSqlTypeNames.INT64
     )
     type_ = "SCALAR_FUNCTION"
     description = "A routine description."
@@ -146,15 +145,15 @@ def test_from_api_repr(target_class):
     assert actual_routine.arguments == [
         RoutineArgument(
             name="x",
-            data_type=bigquery_v2.types.StandardSqlDataType(
-                type_kind=bigquery_v2.types.StandardSqlDataType.TypeKind.INT64
+            data_type=bigquery.standard_sql.StandardSqlDataType(
+                type_kind=bigquery.StandardSqlTypeNames.INT64
             ),
         )
     ]
     assert actual_routine.body == "42"
     assert actual_routine.language == "SQL"
-    assert actual_routine.return_type == bigquery_v2.types.StandardSqlDataType(
-        type_kind=bigquery_v2.types.StandardSqlDataType.TypeKind.INT64
+    assert actual_routine.return_type == bigquery.standard_sql.StandardSqlDataType(
+        type_kind=bigquery.StandardSqlTypeNames.INT64
     )
     assert actual_routine.return_table_type is None
     assert actual_routine.type_ == "SCALAR_FUNCTION"
@@ -168,9 +167,9 @@ def test_from_api_repr_tvf_function(target_class):
     from google.cloud.bigquery.routine import RoutineReference
     from google.cloud.bigquery.routine import RoutineType
 
-    StandardSqlDataType = bigquery_v2.types.StandardSqlDataType
-    StandardSqlField = bigquery_v2.types.StandardSqlField
-    StandardSqlTableType = bigquery_v2.types.StandardSqlTableType
+    StandardSqlDataType = bigquery.standard_sql.StandardSqlDataType
+    StandardSqlField = bigquery.standard_sql.StandardSqlField
+    StandardSqlTableType = bigquery.standard_sql.StandardSqlTableType
 
     creation_time = datetime.datetime(
         2010, 5, 19, 16, 0, 0, tzinfo=google.cloud._helpers.UTC
@@ -216,7 +215,9 @@ def test_from_api_repr_tvf_function(target_class):
     assert actual_routine.arguments == [
         RoutineArgument(
             name="a",
-            data_type=StandardSqlDataType(type_kind=StandardSqlDataType.TypeKind.INT64),
+            data_type=StandardSqlDataType(
+                type_kind=bigquery.StandardSqlTypeNames.INT64
+            ),
         )
     ]
     assert actual_routine.body == "SELECT x FROM UNNEST([1,2,3]) x WHERE x > a"
@@ -226,7 +227,7 @@ def test_from_api_repr_tvf_function(target_class):
         columns=[
             StandardSqlField(
                 name="int_col",
-                type=StandardSqlDataType(type_kind=StandardSqlDataType.TypeKind.INT64),
+                type=StandardSqlDataType(type_kind=bigquery.StandardSqlTypeNames.INT64),
             )
         ]
     )
@@ -460,19 +461,21 @@ def test_set_return_table_type_w_none(object_under_test):
 
 
 def test_set_return_table_type_w_not_none(object_under_test):
-    StandardSqlDataType = bigquery_v2.types.StandardSqlDataType
-    StandardSqlField = bigquery_v2.types.StandardSqlField
-    StandardSqlTableType = bigquery_v2.types.StandardSqlTableType
+    StandardSqlDataType = bigquery.standard_sql.StandardSqlDataType
+    StandardSqlField = bigquery.standard_sql.StandardSqlField
+    StandardSqlTableType = bigquery.standard_sql.StandardSqlTableType
 
     table_type = StandardSqlTableType(
         columns=[
             StandardSqlField(
                 name="int_col",
-                type=StandardSqlDataType(type_kind=StandardSqlDataType.TypeKind.INT64),
+                type=StandardSqlDataType(type_kind=bigquery.StandardSqlTypeNames.INT64),
             ),
             StandardSqlField(
                 name="str_col",
-                type=StandardSqlDataType(type_kind=StandardSqlDataType.TypeKind.STRING),
+                type=StandardSqlDataType(
+                    type_kind=bigquery.StandardSqlTypeNames.STRING
+                ),
             ),
         ]
     )
